==> haskell-threads-0.5.1.6-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-threads.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: threads
version: 0.5.1.6
id: threads-0.5.1.6-2NpdBy0xfDH2xhif8hOk9S
key: threads-0.5.1.6-2NpdBy0xfDH2xhif8hOk9S
license: BSD3
copyright: 2010–2012 Bas van Dijk & Roel van Dijk
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
            Roel van Dijk <vandijk.roel@gmail.com>
stability: experimental
homepage: https://github.com/basvandijk/threads
synopsis: Fork threads and wait for their result
description:
    This package provides functions to fork threads and
    wait for their result, whether it'\''s an exception or a
    normal value.
    .
    Besides waiting for the termination of a single thread
    this packages also provides functions to wait for a
    group of threads to terminate.
    .
    This package is similar to the
    @threadmanager@, @async@ and @spawn@ packages.
    The advantages of this package are:
    .
    * Simpler API.
    .
    * More efficient in both space and time.
    .
    * No space-leak when forking a large number of threads.
    .
    * Correct handling of asynchronous exceptions.
    .
    * GHC specific functionality like @forkOn@ and @forkIOWithUnmask@.
category: Concurrency
author: Bas van Dijk <v.dijk.bas@gmail.com>
        Roel van Dijk <vandijk.roel@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Control.Concurrent.Thread Control.Concurrent.Thread.Group
hidden-modules: Control.Concurrent.Raw
abi: 024c73506799cd018982fceeabb69813
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/threads-0.5.1.6
library-dirs: /usr/lib/ghc-8.2.2/site-local/threads-0.5.1.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/threads-0.5.1.6
hs-libraries: HSthreads-0.5.1.6-2NpdBy0xfDH2xhif8hOk9S
depends:
    base-4.10.1.0 stm-2.4.5.0-7j9Z9j03i0pHiTKIV2qS3x
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             stm-2.4.5.0-7j9Z9j03i0pHiTKIV2qS3x=ad6bbd8e6ded9502ff897b95774cdf26
haddock-interfaces: /usr/share/doc/haskell-threads/html/threads.haddock
haddock-html: /usr/share/doc/haskell-threads/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-threads-0.5.1.6-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-threads.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: threads
version: 0.5.1.6
id: threads-0.5.1.6-CGqqbRFoP19xOZXs8Y9GS
key: threads-0.5.1.6-CGqqbRFoP19xOZXs8Y9GS
license: BSD-3-Clause
copyright: 2010–2012 Bas van Dijk & Roel van Dijk
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
            Roel van Dijk <vandijk.roel@gmail.com>
author: Bas van Dijk <v.dijk.bas@gmail.com>
        Roel van Dijk <vandijk.roel@gmail.com>
stability: experimental
homepage: https://github.com/basvandijk/threads
synopsis: Fork threads and wait for their result
description:
    This package provides functions to fork threads and
    wait for their result, whether it'\''s an exception or a
    normal value.
    .
    Besides waiting for the termination of a single thread
    this packages also provides functions to wait for a
    group of threads to terminate.
    .
    This package is similar to the
    @threadmanager@, @async@ and @spawn@ packages.
    The advantages of this package are:
    .
    * Simpler API.
    .
    * More efficient in both space and time.
    .
    * No space-leak when forking a large number of threads.
    .
    * Correct handling of asynchronous exceptions.
    .
    * GHC specific functionality like @forkOn@ and @forkIOWithUnmask@.
category: Concurrency
abi: 388b535224cddb3979b54c4f79227bcc
exposed: True
exposed-modules:
    Control.Concurrent.Thread Control.Concurrent.Thread.Group
hidden-modules: Control.Concurrent.Raw
import-dirs: /usr/lib/ghc-8.4.3/site-local/threads-0.5.1.6
library-dirs: /usr/lib/ghc-8.4.3/site-local/threads-0.5.1.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/threads-0.5.1.6
hs-libraries: HSthreads-0.5.1.6-CGqqbRFoP19xOZXs8Y9GS
depends:
    base-4.11.1.0 stm-2.4.5.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             stm-2.4.5.0=4e743cb5a370ac3fbade528432951c3f
haddock-interfaces: /usr/share/doc/haskell-threads/html/threads.haddock
haddock-html: /usr/share/doc/haskell-threads/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
